module

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2024 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Overview

Package module provides functionality to work with go modules.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Module

type Module struct {
	Path    string // The module path
	Version string // The module version
}

Module represents a single go module.

func (*Module) String

func (m *Module) String() string

String returns the string representation of a Module.

type Modules

type Modules []Module

Modules represent a collection of go modules.

func NewFromGoModule

func NewFromGoModule(dir string) (*Modules, error)

NewFromGoModule analyzes the go.mod file located in the given directory and returns all direct go module dependencies.

Jump to